@@ -18,6 +18,8 @@ use crate::errors::SynthesisError;
 
 pub trait Assignment<T> {
     fn get(self) -> Result<T, SynthesisError>;
+
+    fn get_ref(&self) -> Result<&T, SynthesisError>;
 }
 
 impl<T> Assignment<T> for Option<T> {
@@ -27,4 +29,11 @@ impl<T> Assignment<T> for Option<T> {
             None => Err(SynthesisError::AssignmentMissing),
         }
     }
+
+    fn get_ref(&self) -> Result<&T, SynthesisError> {
+        match *self {
+            Some(ref v) => Ok(v),
+            None => Err(SynthesisError::AssignmentMissing),
+        }
+    }
 }
